@@ -8,6 +8,7 @@ import os
 import unittest
 
 from PIL import Image, ImageMath
+from PIL._util import py3
 
 import logging
 logger = logging.getLogger(__name__)
@@ -83,7 +84,7 @@ class PillowTestCase(unittest.TestCase):
             self.assertTrue(
                 all(x == y for x, y in zip(a, b)),
                 msg or "got %s, expected %s" % (a, b))
-        except:
+        except Exception:
             self.assertEqual(a, b, msg)
 
     def assert_image(self, im, mode, size, msg=None):
@@ -109,7 +110,7 @@ class PillowTestCase(unittest.TestCase):
                 try:
                     url = test_image_results.upload(a, b)
                     logger.error("Url for test images: %s" % url)
-                except Exception as msg:
+                except Exception:
                     pass
 
             self.fail(msg or "got different content")
@@ -148,11 +149,12 @@ class PillowTestCase(unittest.TestCase):
                 try:
                     url = test_image_results.upload(a, b)
                     logger.error("Url for test images: %s" % url)
-                except:
+                except Exception:
                     pass
             raise e
 
-    def assert_image_similar_tofile(self, a, filename, epsilon, msg=None, mode=None):
+    def assert_image_similar_tofile(self, a, filename, epsilon, msg=None,
+                                    mode=None):
         with Image.open(filename) as img:
             if mode:
                 img = img.convert(mode)
@@ -161,7 +163,6 @@ class PillowTestCase(unittest.TestCase):
     def assert_warning(self, warn_class, func, *args, **kwargs):
         import warnings
 
-        result = None
         with warnings.catch_warnings(record=True) as w:
             # Cause all warnings to always be triggered.
             warnings.simplefilter("always")
@@ -173,7 +174,7 @@ class PillowTestCase(unittest.TestCase):
             if warn_class is None:
                 self.assertEqual(len(w), 0,
                                  "Expected no warnings, got %s" %
-                                 list(v.category for v in w))
+                                 [v.category for v in w])
             else:
                 self.assertGreaterEqual(len(w), 1)
                 found = False
@@ -185,10 +186,20 @@ class PillowTestCase(unittest.TestCase):
         return result
 
     def assert_all_same(self, items, msg=None):
-        self.assertTrue(items.count(items[0]) == len(items), msg)
+        self.assertEqual(items.count(items[0]), len(items), msg)
 
     def assert_not_all_same(self, items, msg=None):
-        self.assertFalse(items.count(items[0]) == len(items), msg)
+        self.assertNotEqual(items.count(items[0]), len(items), msg)
+
+    def assert_tuple_approx_equal(self, actuals, targets, threshold, msg):
+        """Tests if actuals has values within threshold from targets"""
+
+        value = True
+        for i, target in enumerate(targets):
+            value *= (target - threshold <= actuals[i] <= target + threshold)
+
+        self.assertTrue(value,
+                        msg + ': ' + repr(actuals) + ' != ' + repr(targets))
 
     def skipKnownBadTest(self, msg=None, platform=None,
                          travis=None, interpreter=None):
@@ -229,23 +240,24 @@ class PillowTestCase(unittest.TestCase):
 
 @unittest.skipIf(sys.platform.startswith('win32'), "requires Unix or macOS")
 class PillowLeakTestCase(PillowTestCase):
-    # requires unix/osx
+    # requires unix/macOS
     iterations = 100  # count
     mem_limit = 512  # k
 
     def _get_mem_usage(self):
         """
         Gets the RUSAGE memory usage, returns in K. Encapsulates the difference
-        between OSX and Linux rss reporting
+        between macOS and Linux rss reporting
 
-        :returns; memory usage in kilobytes
+        :returns: memory usage in kilobytes
         """
 
         from resource import getrusage, RUSAGE_SELF
         mem = getrusage(RUSAGE_SELF).ru_maxrss
         if sys.platform == 'darwin':
             # man 2 getrusage:
-            #     ru_maxrss    the maximum resident set size utilized (in bytes).
+            #     ru_maxrss
+            # This is the maximum resident set size utilized (in bytes).
             return mem / 1024  # Kb
         else:
             # linux
@@ -259,13 +271,16 @@ class PillowLeakTestCase(PillowTestCase):
         for cycle in range(self.iterations):
             core()
             mem = (self._get_mem_usage() - start_mem)
-            self.assertLess(mem, self.mem_limit,
-                            msg='memory usage limit exceeded in iteration %d' % cycle)
+            msg = 'memory usage limit exceeded in iteration %d' % cycle
+            self.assertLess(mem, self.mem_limit, msg)
 
 
 # helpers
 
-py3 = sys.version_info.major >= 3
+if not py3:
+    # Remove DeprecationWarning in Python 3
+    PillowTestCase.assertRaisesRegex = PillowTestCase.assertRaisesRegexp
+    PillowTestCase.assertRegex = PillowTestCase.assertRegexpMatches
 
 
 def fromstring(data):
