@@ -39,7 +39,7 @@ class TestImageQuantize(PillowTestCase):
     def test_rgba_quantize(self):
         image = hopper('RGBA')
         image.quantize()
-        self.assertRaises(Exception, image.quantize, method=0)
+        self.assertRaises(ValueError, image.quantize, method=0)
 
     def test_quantize(self):
         image = Image.open('Tests/images/caption_6_33_22.png').convert('RGB')
