@@ -13,22 +13,25 @@ class TestImageOpsUsm(PillowTestCase):
     def test_ops_api(self):
 
         i = self.assert_warning(DeprecationWarning,
-            ImageOps.gaussian_blur, im, 2.0)
+                                ImageOps.gaussian_blur, im, 2.0)
+        self.assertEqual(i.mode, "RGB")
+        self.assertEqual(i.size, (128, 128))
+
+        i = self.assert_warning(DeprecationWarning, ImageOps.box_blur, im, 1)
+        self.assertEqual(i.mode, "RGB")
+        self.assertEqual(i.size, (128, 128))
+
+        i = self.assert_warning(DeprecationWarning, ImageOps.gblur, im, 2.0)
         self.assertEqual(i.mode, "RGB")
         self.assertEqual(i.size, (128, 128))
 
         i = self.assert_warning(DeprecationWarning,
-            ImageOps.gblur, im, 2.0)
+                                ImageOps.unsharp_mask, im, 2.0, 125, 8)
         self.assertEqual(i.mode, "RGB")
         self.assertEqual(i.size, (128, 128))
 
         i = self.assert_warning(DeprecationWarning,
-            ImageOps.unsharp_mask, im, 2.0, 125, 8)
-        self.assertEqual(i.mode, "RGB")
-        self.assertEqual(i.size, (128, 128))
-
-        i = self.assert_warning(DeprecationWarning,
-            ImageOps.usm, im, 2.0, 125, 8)
+                                ImageOps.usm, im, 2.0, 125, 8)
         self.assertEqual(i.mode, "RGB")
         self.assertEqual(i.size, (128, 128))
 
