@@ -5,7 +5,7 @@ from __future__ import print_function
 import sys
 import os
 
-from PIL import Image, ImageDraw, ImageFilter, ImageMath
+from PIL import Image
 from PIL import features
 
 try:
@@ -26,6 +26,7 @@ def testimage():
     """
     PIL lets you create in-memory images with various pixel types:
 
+    >>> from PIL import Image, ImageDraw, ImageFilter, ImageMath
     >>> im = Image.new("1", (128, 128)) # monochrome
     >>> _info(im)
     (None, '1', (128, 128))
@@ -161,7 +162,7 @@ if __name__ == "__main__":
     exit_status = 0
 
     print("-"*68)
-    print("Pillow", Image.PILLOW_VERSION, "TEST SUMMARY ")
+    print("Pillow", Image.__version__, "TEST SUMMARY ")
     print("-"*68)
     print("Python modules loaded from", os.path.dirname(Image.__file__))
     print("Binary modules loaded from", os.path.dirname(Image.core.__file__))
